@@ -10,6 +10,7 @@ from mvvmQt.Events import Event
 from mvvmQt.Elements import Element
 from mvvmQt.attrConfig import ElementAttr
 from mvvmQt.alignConfig import ElementAlign
+from mvvmQt.Observable import Computed
 
 class Parser:
     ElementAttrConfig = ElementAttr
@@ -55,18 +56,27 @@ class Parser:
         c = re.compile(r'\<(.*?)\>')
         return c.findall(s)[0].split(' ')[0]
 
+    def not_value(self, v):
+        return not v[0]
+
     def loopChild(self, e, parent=None):
         dom = pq(e)
         tagName = self.tagName(dom)
         #检查是否为属性设置
         if tagName.startswith('attr'):
             ob_value = dom.attr('ob')
+            is_not = False
             if ob_value:
+                if ob_value.startswith('!'):
+                    is_not = True
+                    ob_value = ob_value.replace('!', '')
                 arr_index = re.findall(r'.*\[(\d+)\]', ob_value)
                 if len(arr_index) > 0:
-                    value = getattr(self.models, ob_value.replace("[%s]" % arr_index[0], ''))[int(arr_index)]
+                    value = getattr(self.models, ob_value.replace("[%s]" % arr_index[0], ''))[int(arr_index[0])]
                 else:
                     value = getattr(self.models, ob_value)
+                if is_not:
+                    value = Computed([value], self.not_value)
             else:
                 value = dom.attr('v')
             return self.AttributeObj(tagName.replace('attr-', ''), value, dom)
